Index: /trunk/src/VBox/Devices/Parallel/DevParallel.cpp
===================================================================
--- /trunk/src/VBox/Devices/Parallel/DevParallel.cpp	(revision 64275)
+++ /trunk/src/VBox/Devices/Parallel/DevParallel.cpp	(revision 64276)
@@ -160,6 +160,6 @@
 *********************************************************************************************************************************/
 RT_C_DECLS_BEGIN
-PDMBOTHCBDECL(int) parallelIOPortRead(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT Port, uint32_t *pu32, unsigned cb);
-PDMBOTHCBDECL(int) parallelIOPortWrite(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT Port, uint32_t u32, unsigned cb);
+PDMBOTHCBDECL(int) parallelIOPortRead(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT uPort, uint32_t *pu32, unsigned cb);
+PDMBOTHCBDECL(int) parallelIOPortWrite(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT uPort, uint32_t u32, unsigned cb);
 #if 0
 PDMBOTHCBDECL(int) parallelIOPortReadECP(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT Port, uint32_t *pu32, unsigned cb);
@@ -319,5 +319,5 @@
  * @callback_method_impl{FNIOMIOPORTOUT}
  */
-PDMBOTHCBDECL(int) parallelIOPortWrite(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT Port, uint32_t u32, unsigned cb)
+PDMBOTHCBDECL(int) parallelIOPortWrite(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT uPort, uint32_t u32, unsigned cb)
 {
     PARALLELPORT *pThis = PDMINS_2_DATA(pDevIns, PPARALLELPORT);
@@ -329,8 +329,8 @@
         uint8_t u8 = u32;
 
-        Log2(("%s: port %#06x val %#04x\n", __FUNCTION__, Port, u32));
-
-        Port &= 7;
-        switch (Port)
+        Log2(("%s: port %#06x val %#04x\n", __FUNCTION__, uPort, u32));
+
+        uPort &= 7;
+        switch (uPort)
         {
             case 0:
@@ -417,5 +417,5 @@
     }
     else
-        AssertMsgFailed(("Port=%#x cb=%d u32=%#x\n", Port, cb, u32));
+        AssertMsgFailed(("Port=%#x cb=%d u32=%#x\n", uPort, cb, u32));
 
     return rc;
@@ -426,5 +426,5 @@
  * @callback_method_impl{FNIOMIOPORTIN}
  */
-PDMBOTHCBDECL(int) parallelIOPortRead(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT Port, uint32_t *pu32, unsigned cb)
+PDMBOTHCBDECL(int) parallelIOPortRead(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT uPort, uint32_t *pu32, unsigned cb)
 {
     PARALLELPORT *pThis = PDMINS_2_DATA(pDevIns, PARALLELPORT *);
@@ -434,6 +434,6 @@
     if (cb == 1)
     {
-        Port &= 7;
-        switch (Port)
+        uPort &= 7;
+        switch (uPort)
         {
             case 0:
Index: /trunk/src/VBox/Devices/Parallel/DrvHostParallel.cpp
===================================================================
--- /trunk/src/VBox/Devices/Parallel/DrvHostParallel.cpp	(revision 64275)
+++ /trunk/src/VBox/Devices/Parallel/DrvHostParallel.cpp	(revision 64276)
@@ -47,8 +47,11 @@
 #endif
 
-/** @def VBOX_WITH_WIN_PARPORT_SUP *
+/** @def VBOX_WITH_WIN_PARPORT_SUP
  * Indicates whether to use the generic direct hardware access or host specific
  * code to access the parallel port.
  */
+#if defined(DOXYGEN_RUNNING)
+# define VBOX_WITH_WIN_PARPORT_SUP
+#endif
 #if defined(RT_OS_LINUX)
 # undef VBOX_WITH_WIN_PARPORT_SUP
@@ -270,5 +273,5 @@
 
 /**
- * @interface_method_impl{FNPDMDRVREQHANDLERR0}
+ * @callback_method_impl{FNPDMDRVREQHANDLERR0}
  */
 PDMBOTHCBDECL(int) drvR0HostParallelReqHandler(PPDMDRVINS pDrvIns, uint32_t uOperation, uint64_t u64Arg)
Index: /trunk/src/VBox/Devices/Serial/DevSerial.cpp
===================================================================
--- /trunk/src/VBox/Devices/Serial/DevSerial.cpp	(revision 64275)
+++ /trunk/src/VBox/Devices/Serial/DevSerial.cpp	(revision 64276)
@@ -856,5 +856,5 @@
  * @callback_method_impl{FNIOMIOPORTOUT}
  */
-PDMBOTHCBDECL(int) serialIOPortWrite(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT Port, uint32_t u32, unsigned cb)
+PDMBOTHCBDECL(int) serialIOPortWrite(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT uPort, uint32_t u32, unsigned cb)
 {
     PDEVSERIAL pThis = PDMINS_2_DATA(pDevIns, PDEVSERIAL);
@@ -865,10 +865,10 @@
     if (cb == 1)
     {
-        Log2(("%s: port %#06x val %#04x\n", __FUNCTION__, Port, u32));
-        rc = serial_ioport_write(pThis, Port, u32);
+        Log2(("%s: port %#06x val %#04x\n", __FUNCTION__, uPort, u32));
+        rc = serial_ioport_write(pThis, uPort, u32);
     }
     else
     {
-        AssertMsgFailed(("Port=%#x cb=%d u32=%#x\n", Port, cb, u32));
+        AssertMsgFailed(("uPort=%#x cb=%d u32=%#x\n", uPort, cb, u32));
         rc = VINF_SUCCESS;
     }
@@ -881,5 +881,5 @@
  * @callback_method_impl{FNIOMIOPORTIN}
  */
-PDMBOTHCBDECL(int) serialIOPortRead(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT Port, uint32_t *pu32, unsigned cb)
+PDMBOTHCBDECL(int) serialIOPortRead(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT uPort, uint32_t *pu32, unsigned cb)
 {
     PDEVSERIAL pThis = PDMINS_2_DATA(pDevIns, PDEVSERIAL);
@@ -890,6 +890,6 @@
     if (cb == 1)
     {
-        *pu32 = serial_ioport_read(pThis, Port, &rc);
-        Log2(("%s: port %#06x val %#04x\n", __FUNCTION__, Port, *pu32));
+        *pu32 = serial_ioport_read(pThis, uPort, &rc);
+        Log2(("%s: port %#06x val %#04x\n", __FUNCTION__, uPort, *pu32));
     }
     else
Index: /trunk/src/VBox/Devices/Serial/DrvHostSerial.cpp
===================================================================
--- /trunk/src/VBox/Devices/Serial/DrvHostSerial.cpp	(revision 64275)
+++ /trunk/src/VBox/Devices/Serial/DrvHostSerial.cpp	(revision 64276)
@@ -450,6 +450,6 @@
  *
  * @returns VINF_SUCCESS.
- * @param   ThreadSelf  Thread handle to this thread.
- * @param   pvUser      User argument.
+ * @param   pDrvIns     PDM driver instance data.
+ * @param   pThread     The PDM thread data.
  */
 static DECLCALLBACK(int) drvHostSerialSendThread(PPDMDRVINS pDrvIns, PPDMTHREAD pThread)
@@ -566,6 +566,7 @@
  * @param     pThread     The send thread.
  */
-static DECLCALLBACK(int) drvHostSerialWakeupSendThread(PPDMDRVINS pDrvIns, PPDMTHREAD /*pThread*/)
+static DECLCALLBACK(int) drvHostSerialWakeupSendThread(PPDMDRVINS pDrvIns, PPDMTHREAD pThread)
 {
+    RT_NOREF(pThread);
     PDRVHOSTSERIAL pThis = PDMINS_2_DATA(pDrvIns, PDRVHOSTSERIAL);
     int rc;
@@ -592,6 +593,6 @@
  *
  * @returns VINF_SUCCESS.
- * @param   ThreadSelf  Thread handle to this thread.
- * @param   pvUser      User argument.
+ * @param   pDrvIns     PDM driver instance data.
+ * @param   pThread     The PDM thread data.
  */
 static DECLCALLBACK(int) drvHostSerialRecvThread(PPDMDRVINS pDrvIns, PPDMTHREAD pThread)
@@ -855,12 +856,13 @@
 
 /**
- * Unblock the send thread so it can respond to a state change.
+ * Unblock the receive thread so it can respond to a state change.
  *
  * @returns a VBox status code.
  * @param     pDrvIns     The driver instance.
- * @param     pThread     The send thread.
- */
-static DECLCALLBACK(int) drvHostSerialWakeupRecvThread(PPDMDRVINS pDrvIns, PPDMTHREAD /*pThread*/)
+ * @param     pThread     The receive thread.
+ */
+static DECLCALLBACK(int) drvHostSerialWakeupRecvThread(PPDMDRVINS pDrvIns, PPDMTHREAD pThread)
 {
+    RT_NOREF(pThread);
     PDRVHOSTSERIAL pThis = PDMINS_2_DATA(pDrvIns, PDRVHOSTSERIAL);
 #if defined(RT_OS_LINUX) || defined(RT_OS_DARWIN) || defined(RT_OS_SOLARIS) || defined(RT_OS_FREEBSD)
@@ -887,6 +889,6 @@
  *
  * @returns VINF_SUCCESS.
- * @param   ThreadSelf  Thread handle to this thread.
- * @param   pvUser      User argument.
+ * @param   pDrvIns     PDM driver instance data.
+ * @param   pThread     The PDM thread data.
  */
 static DECLCALLBACK(int) drvHostSerialMonitorThread(PPDMDRVINS pDrvIns, PPDMTHREAD pThread)
@@ -1151,6 +1153,7 @@
  * @copydoc FNPDMDRVCONSTRUCT
  */
-static DECLCALLBACK(int) drvHostSerialConstruct(PPDMDRVINS pDrvIns, PCFGMNODE pCfg, uint32_t /*fFlags*/)
+static DECLCALLBACK(int) drvHostSerialConstruct(PPDMDRVINS pDrvIns, PCFGMNODE pCfg, uint32_t fFlags)
 {
+    RT_NOREF1(fFlags);
     PDRVHOSTSERIAL pThis = PDMINS_2_DATA(pDrvIns, PDRVHOSTSERIAL);
     LogFlow(("%s: iInstance=%d\n", __FUNCTION__, pDrvIns->iInstance));

Index: /trunk/include/VBox/vmm/pdmifs.h
===================================================================
--- /trunk/include/VBox/vmm/pdmifs.h	(revision 64275)
+++ /trunk/include/VBox/vmm/pdmifs.h	(revision 64276)
@@ -1249,8 +1249,8 @@
      * @param   pInterface      Pointer to the interface structure containing the called function pointer.
      * @param   pvBuf           Where to store the read bits.
      * @param   cbRead          Number of bytes to read/bytes actually read.
      * @thread  Any thread.
      */
-    DECLR3CALLBACKMEMBER(int, pfnRead,(PPDMISTREAM pInterface, void *pvBuf, size_t *cbRead));
+    DECLR3CALLBACKMEMBER(int, pfnRead,(PPDMISTREAM pInterface, void *pvBuf, size_t *pcbRead));
 
     /**
@@ -1260,8 +1260,8 @@
      * @param   pInterface      Pointer to the interface structure containing the called function pointer.
      * @param   pvBuf           Where to store the write bits.
      * @param   cbWrite         Number of bytes to write/bytes actually written.
      * @thread  Any thread.
      */
-    DECLR3CALLBACKMEMBER(int, pfnWrite,(PPDMISTREAM pInterface, const void *pvBuf, size_t *cbWrite));
+    DECLR3CALLBACKMEMBER(int, pfnWrite,(PPDMISTREAM pInterface, const void *pvBuf, size_t *pcbWrite));
 } PDMISTREAM;
 /** PDMISTREAM interface ID. */
@@ -1249,8 +1249,8 @@
      * @param   pInterface      Pointer to the interface structure containing the called function pointer.
      * @param   pvBuf           Where to store the read bits.
-     * @param   cbRead          Number of bytes to read/bytes actually read.
+     * @param   pcbRead         Number of bytes to read/bytes actually read.
      * @thread  Any thread.
      */
@@ -1260,8 +1260,8 @@
      * @param   pInterface      Pointer to the interface structure containing the called function pointer.
      * @param   pvBuf           Where to store the write bits.
-     * @param   cbWrite         Number of bytes to write/bytes actually written.
+     * @param   pcbWrite        Number of bytes to write/bytes actually written.
      * @thread  Any thread.
      */